// Fonction pour marquer la page active
function markActivePage() {
    const currentPath = window.location.pathname;
    const links = document.querySelectorAll('.tree-link');
    
    links.forEach(link => {
        const linkPath = link.getAttribute('href');
        const currentFile = currentPath.split('/').pop();
        const linkFile = linkPath.split('/').pop();
        
        if (currentFile === linkFile) {
            link.classList.add('active');
        } else {
            link.classList.remove('active');
        }
    });
}

// Gestionnaire d'événements pour les en-têtes d'arborescence
document.addEventListener('click', function(e) {
    if (e.target.classList.contains('tree-header')) {
        const icon = e.target.querySelector('i');
        if (icon) {
            const isExpanded = e.target.getAttribute('aria-expanded') === 'true';
            icon.style.transform = isExpanded ? 'rotate(90deg)' : 'rotate(0deg)';
        }
    }
});

// Initialisation au chargement de la page
document.addEventListener('DOMContentLoaded', function() {
    markActivePage();
});

// Fonction de recherche globale
document.addEventListener('DOMContentLoaded', function() {
    const searchInput = document.getElementById('searchInput');
    const searchButton = document.getElementById('searchButton');
    const searchResults = document.getElementById('searchResults');
    let searchTimeout;

    // Index de recherche
    const searchIndex = {
        'hsrp': {
            title: 'HSRP/VRRP',
            url: 'content/reseaux/hsrp.html',
            category: 'Réseaux',
            keywords: [
                'redondance', 'routeur', 'basculement', 'priorité', 'suivi', 'minuteurs', 'préemption',
                'hot standby', 'routeur virtuel', 'passerelle', 'basculement', 'équilibrage de charge', 'cisco',
                'paquets hello', 'temps de maintien', 'authentification', 'état', 'actif', 'standby',
                'suivi d\'interface', 'préemption', 'groupe', 'ip virtuelle', 'adresse mac', 'arp',
                'redondance', 'haute disponibilité', 'réseau', 'commutation', 'routage',
                'configuration', 'dépannage', 'débogage', 'commandes show', 'vérification',
                'cisco ios', 'routeur', 'commutateur', 'couche 3', 'couche 2', 'protocole', 'protocole de routage'
            ]
        },
        'dhcp': {
            title: 'DHCP',
            url: 'content/reseaux/dhcp.html',
            category: 'Réseaux',
            keywords: [
                'adresse', 'ip', 'réservation', 'pool', 'plage', 'relais', 'hôte dynamique',
                'protocole de configuration', 'bail', 'renouvellement', 'rebinding', 'dns', 'passerelle',
                'sous-réseau', 'masque', 'exclusion', 'option', 'fournisseur', 'classe', 'liaison',
                'autorisation', 'conflit', 'détection', 'basculement', 'sauvegarde', 'primaire',
                'secondaire', 'base de données', 'journalisation', 'surveillance', 'sécurité',
                'windows server', 'linux', 'isc dhcp', 'dnsmasq', 'configuration',
                'dépannage', 'débogage', 'ip helper', 'agent relais', 'dhcp snooping',
                'dhcp guard', 'dhcp option 82', 'dhcp option 43', 'dhcp option 60'
            ]
        },
        'vtp': {
            title: 'VTP',
            url: 'content/reseaux/vtp.html',
            category: 'Réseaux',
            keywords: [
                'vlan', 'trunk', 'domaine', 'synchronisation', 'serveur', 'client', 'transparent',
                'version', 'élagage', 'annonce', 'révision', 'base de données', 'cisco',
                'commutation', 'réseau', 'gestion', 'configuration', 'propagation',
                'sécurité', 'authentification', 'mode', 'statut', 'résumé', 'étendu',
                'normal', 'désactivé', 'domaine', 'mot de passe', 'numéro de révision',
                'base de données vlan', 'configuration vlan', 'trunking vlan', 'élagage vlan',
                'gestion vlan', 'sécurité vlan', 'dépannage vlan', 'vérification vlan',
                'show vtp', 'show vlan', 'show interfaces trunk', 'show spanning-tree'
            ]
        },
        'acl': {
            title: 'ACLs',
            url: 'content/reseaux/acl.html',
            category: 'Réseaux',
            keywords: [
                'filtrage', 'sécurité', 'accès', 'liste', 'standard', 'étendue', 'ip',
                'tcp', 'udp', 'icmp', 'port', 'source', 'destination', 'masque générique',
                'masque', 'autoriser', 'refuser', 'établi', 'réflexif', 'basé sur le temps',
                'dynamique', 'nommé', 'numéroté', 'interface', 'direction', 'entrant',
                'sortant', 'journalisation', 'statistiques', 'vérification',
                'cisco ios', 'routeur', 'commutateur', 'pare-feu', 'sécurité',
                'dépannage', 'débogage', 'show access-list', 'show ip access-list',
                'configuration acl', 'vérification acl', 'journalisation acl'
            ]
        },
        'zabbix': {
            title: 'Zabbix',
            url: 'content/logiciels/zabbix.html',
            category: 'Logiciels',
            keywords: [
                'surveillance', 'monitoring', 'alertes', 'métriques', 'tableaux de bord', 'éléments',
                'déclencheurs', 'actions', 'modèles', 'hôtes', 'groupes', 'découverte',
                'auto-enregistrement', 'agent', 'proxy', 'serveur', 'interface web',
                'graphiques', 'cartes', 'écrans', 'rapports', 'maintenance', 'inventaire',
                'api', 'intégration', 'notification', 'email', 'sms', 'script',
                'performance', 'disponibilité', 'tendances', 'historique',
                'installation', 'configuration', 'administration', 'maintenance',
                'dépannage', 'débogage', 'journaux', 'base de données', 'sauvegarde', 'restauration',
                'mise à niveau', 'sécurité', 'authentification', 'autorisation', 'permissions'
            ]
        },
        'glpi': {
            title: 'GLPI',
            url: 'content/logiciels/glpi.html',
            category: 'Logiciels',
            keywords: [
                'inventaire', 'tickets', 'gestion', 'parc', 'informatique', 'actifs',
                'helpdesk', 'itil', 'cmdb', 'configuration', 'gestion', 'base de données',
                'utilisateurs', 'groupes', 'profils', 'droits', 'permissions', 'catégories',
                'emplacements', 'entités', 'logiciels', 'licences', 'contrats', 'fournisseurs',
                'documents', 'base de connaissances', 'rapports', 'statistiques', 'plugins',
                'fusioninventory', 'ocs', 'snmp', 'réseau', 'imprimante', 'ordinateur',
                'installation', 'configuration', 'administration', 'maintenance',
                'dépannage', 'débogage', 'journaux', 'sauvegarde', 'restauration', 'mise à niveau',
                'sécurité', 'authentification', 'ldap', 'saml', 'oauth', '2fa'
            ]
        },
        'apache2': {
            title: 'Apache2',
            url: 'content/logiciels/apache2.html',
            category: 'Logiciels',
            keywords: [
                'serveur', 'web', 'http', 'https', 'hôte virtuel', 'modules', 'ssl',
                'tls', 'certificat', 'sécurité', 'authentification', 'autorisation',
                'htaccess', 'htpasswd', 'mod_rewrite', 'mod_ssl', 'mod_proxy',
                'mod_security', 'mod_headers', 'mod_expires', 'mod_deflate',
                'hôtes virtuels', 'répertoire', 'emplacement', 'proxy', 'équilibrage de charge',
                'mise en cache', 'compression', 'journalisation', 'erreur', 'accès', 'personnalisé',
                'configuration', 'mpm', 'worker', 'prefork', 'event', 'php',
                'python', 'perl', 'cgi', 'fastcgi', 'wsgi',
                'installation', 'configuration', 'administration', 'maintenance',
                'dépannage', 'débogage', 'journaux', 'sécurité', 'performance',
                'optimisation', 'sauvegarde', 'restauration', 'mise à niveau'
            ]
        },
        'heartbeat': {
            title: 'Heartbeat',
            url: 'content/logiciels/heartbeat.html',
            category: 'Logiciels',
            keywords: [
                'haute', 'disponibilité', 'cluster', 'basculement', 'ressources',
                'basculement', 'équilibrage de charge', 'drbd', 'pacemaker', 'corosync',
                'stonith', 'fencing', 'quorum', 'contraintes', 'colocation',
                'emplacement', 'ordre', 'score', 'priorité', 'surveillance',
                'contrôle de santé', 'agent de ressource', 'ocf', 'lsb', 'systemd',
                'service', 'ip', 'système de fichiers', 'mysql', 'apache', 'ip virtuelle',
                'synchronisation', 'réplication', 'split brain', 'maintenance',
                'installation', 'configuration', 'administration', 'maintenance',
                'dépannage', 'débogage', 'journaux', 'sécurité', 'performance',
                'optimisation', 'sauvegarde', 'restauration', 'mise à niveau'
            ]
        },
        'hmail': {
            title: 'hMailServer',
            url: 'content/logiciels/hmail.html',
            category: 'Logiciels',
            keywords: [
                'mail', 'smtp', 'pop3', 'imap', 'antispam', 'antivirus', 'serveur',
                'email', 'domaine', 'compte', 'alias', 'liste de distribution', 'route',
                'relais', 'authentification', 'ssl', 'tls', 'chiffrement', 'sécurité',
                'spam', 'virus', 'filtre', 'règle', 'greylisting', 'dkim', 'spf',
                'dmarc', 'liste noire', 'liste blanche', 'journalisation', 'sauvegarde', 'restauration',
                'administration', 'api', 'script', 'événement', 'planificateur', 'file d\'attente',
                'livraison', 'rebond', 'transfert', 'catch-all',
                'installation', 'configuration', 'administration', 'maintenance',
                'dépannage', 'débogage', 'journaux', 'sécurité', 'performance',
                'optimisation', 'sauvegarde', 'restauration', 'mise à niveau'
            ]
        },
        'ad': {
            title: 'Active Directory',
            url: 'content/logiciels/ad.html',
            category: 'Logiciels',
            keywords: [
                'domaine', 'utilisateurs', 'gpo', 'dns', 'dhcp', 'authentification',
                'autorisation', 'stratégie de groupe', 'unité organisationnelle', 'ou',
                'groupe de sécurité', 'groupe de distribution', 'schéma', 'forêt',
                'arbre', 'contrôleur de domaine', 'réplication', 'fsmo', 'rôles',
                'approbation', 'site', 'sous-réseau', 'réplication', 'sysvol', 'netlogon',
                'kerberos', 'ntlm', 'ldap', 'adsi', 'powershell', 'délégation',
                'permissions', 'héritage', 'bloquer l\'héritage', 'appliquer',
                'boucle', 'préférence', 'priorité', 'wmi', 'ciblage au niveau élément',
                'installation', 'configuration', 'administration', 'maintenance',
                'dépannage', 'débogage', 'journaux', 'sécurité', 'performance',
                'optimisation', 'sauvegarde', 'restauration', 'mise à niveau', 'migration'
            ]
        },
        'nextcloud': {
            title: 'Nextcloud',
            url: 'content/logiciels/nextcloud.html',
            category: 'Logiciels',
            keywords: [
                'cloud', 'partage', 'fichiers', 'collaboration', 'synchronisation',
                'stockage', 'chiffrement', 'sécurité', 'authentification', 'ldap',
                'saml', 'oauth', '2fa', 'mfa', 'partage', 'permissions', 'acl',
                'versionnage', 'corbeille', 'aperçu', 'bureau',
                'collabora', 'onlyoffice', 'calendrier', 'contacts', 'tâches',
                'notes', 'deck', 'talk', 'meet', 'jitsi', 'intégration',
                'api', 'webdav', 'caldav', 'carddav', 'mobile', 'bureau',
                'client', 'synchronisation', 'sauvegarde', 'restauration', 'mise à niveau', 'maintenance',
                'installation', 'configuration', 'administration', 'maintenance',
                'dépannage', 'débogage', 'journaux', 'sécurité', 'performance',
                'optimisation', 'sauvegarde', 'restauration', 'mise à niveau', 'migration'
            ]
        },
        'pfsense': {
            title: 'pfSense',
            url: 'content/logiciels/pfsense.html',
            category: 'Logiciels',
            keywords: [
                'pare-feu', 'acl', 'nat', 'dhcp', 'dns', 'vpn', 'ssl', 'tls', 'ssh', 'http', 'https', 'ftp', 'smtp', 'pop3', 'imap', 'ldap', 'saml', 'oauth', '2fa', 'mfa', 'partage', 'permissions', 'acl',
                'versionnage', 'corbeille', 'aperçu', 'bureau',
                'collabora', 'onlyoffice', 'calendrier', 'contacts', 'tâches',
                'notes', 'deck', 'talk', 'meet', 'jitsi', 'intégration',
                'api', 'webdav', 'caldav', 'carddav', 'mobile', 'bureau',
                'client', 'synchronisation', 'sauvegarde', 'restauration', 'mise à niveau', 'maintenance',
                'installation', 'configuration', 'administration', 'maintenance'
            ]
        },
        'powershell': {
            title: 'Scripts PowerShell',
            url: 'content/logiciels/powershell.html',
            category: 'Logiciels',
            keywords: [
                'script', 'automatisation', 'administration', 'windows', 'cmdlet', 'module',
                'variable', 'boucle', 'condition', 'fonction', 'paramètre', 'pipeline',
                'objet', 'tableau', 'hash table', 'chaîne', 'nombre', 'date',
                'fichier', 'répertoire', 'permission', 'utilisateur', 'groupe',
                'service', 'processus', 'registre', 'wmi', 'cim', 'remoting',
                'job', 'workflow', 'profile', 'session', 'erreur', 'exception',
                'journalisation', 'débogage', 'test', 'unitaire', 'pester',
                'active directory', 'exchange', 'sharepoint', 'sql server',
                'azure', 'aws', 'vmware', 'hyper-v', 'docker', 'kubernetes',
                'sécurité', 'chiffrement', 'certificat', 'authentification',
                'api', 'rest', 'soap', 'json', 'xml', 'csv', 'excel',
                'rapport', 'graphique', 'interface', 'gui', 'formulaire',
                'scheduled task', 'tâche planifiée', 'cron', 'démarrage',
                'maintenance', 'nettoyage', 'archivage', 'sauvegarde',
                'monitoring', 'surveillance', 'alerte', 'performance',
                'dépannage', 'diagnostic', 'analyse', 'optimisation',
                'documentation', 'commentaire', 'aide', 'exemple', 'tutoriel'
            ]
        },
    };

    function performSearch() {
        const searchTerm = searchInput.value.trim().toLowerCase();
        if (!searchTerm) {
            searchResults.style.display = 'none';
            return;
        }

        const results = [];
        
        // Recherche dans l'index
        for (const [key, page] of Object.entries(searchIndex)) {
            let score = 0;
            let matchDetails = [];

            // Recherche dans le titre (score plus élevé)
            if (page.title.toLowerCase().includes(searchTerm)) {
                score += 3;
                matchDetails.push('Titre');
            }

            // Recherche dans la catégorie
            if (page.category.toLowerCase().includes(searchTerm)) {
                score += 2;
                matchDetails.push('Catégorie');
            }

            // Recherche dans les mots-clés
            const matchingKeywords = page.keywords.filter(keyword => 
                keyword.toLowerCase().includes(searchTerm)
            );

            if (matchingKeywords.length > 0) {
                score += matchingKeywords.length;
                matchDetails.push(`Mots-clés: ${matchingKeywords.slice(0, 3).join(', ')}${matchingKeywords.length > 3 ? '...' : ''}`);
            }

            if (score > 0) {
                results.push({
                    title: page.title,
                    url: page.url,
                    category: page.category,
                    score: score,
                    match: matchDetails.join(' | ')
                });
            }
        }

        // Tri des résultats par score
        results.sort((a, b) => b.score - a.score);

        // Affichage des résultats
        if (results.length > 0) {
            searchResults.innerHTML = `
                <div class="search-results-header">
                    <span>${results.length} résultat(s) trouvé(s)</span>
                </div>
                <div class="search-results-list">
                    ${results.map(result => `
                        <a href="${result.url}" class="search-result-item">
                            <div class="result-title">${result.title}</div>
                            <div class="result-category">${result.category}</div>
                            <div class="result-match">${result.match}</div>
                        </a>
                    `).join('')}
                </div>
            `;
            searchResults.style.display = 'block';
        } else {
            searchResults.innerHTML = '<div class="no-results">Aucun résultat trouvé</div>';
            searchResults.style.display = 'block';
        }
    }

    // Gestion des événements de recherche
    if (searchButton && searchInput) {
        searchButton.addEventListener('click', performSearch);
        
        // Recherche en temps réel avec délai
        searchInput.addEventListener('input', function() {
            clearTimeout(searchTimeout);
            searchTimeout = setTimeout(performSearch, 300);
        });

        // Recherche avec la touche Entrée
        searchInput.addEventListener('keypress', function(e) {
            if (e.key === 'Enter') {
                performSearch();
            }
        });
    }
}); 